ErrorFormatter class abstract
Converts a LogRecord and its context into an HTTP request payload.
Implement this interface to support different notification services (e.g. Slack, Discord, PagerDuty) while reusing HttpErrorExporter for the transport layer.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
format(
LogRecord error, List< LogRecord> contextLogs, Map<String, String> metadata) → Map<String, dynamic> - Builds the JSON-encodable payload to deliver to the remote endpoint.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited