oklog_slack library
oklog Slack integration.
Import this library to use SlackErrorExporter and SlackPayloadFormatter for sending error reports to a Slack channel via an Incoming Webhook.
import 'package:oklog/oklog.dart';
import 'package:oklog/oklog_slack.dart';
Classes
- SlackErrorExporter
- A convenience ErrorExporter that sends error reports to a Slack channel via an Incoming Webhook URL.
- SlackPayloadFormatter
- An ErrorFormatter that produces a Slack Block Kit message payload.